@@ -27,6 +27,7 @@ class SequenceField(Field):
     ''' Base class for Fields which are an iterable collection of objects in which
         every child element is of the same type'''
     
+    is_sequence_field = True
     valid_modifiers = LIST_MODIFIERS
     
     def __init__(self, item_type, min_capacity=None, max_capacity=None, 
@@ -66,7 +67,7 @@ class SequenceField(Field):
         ''' Returns the names of the value type's sub-fields'''
         return self.item_type.subfields()
     
-    def dereference(self, session, ref, allow_none=False):
+    def _dereference(self, session, ref, allow_none=False):
         return self.item_type.dereference(session, ref, allow_none=allow_none)
 
     def wrap_value(self, value):
@@ -144,9 +145,7 @@ class SequenceField(Field):
 
 class ListField(SequenceField):
     ''' Field representing a python list.
-        
-        .. seealso:: :class:`SequenceField`'''
-
+    '''        
     def __init__(self, item_type, **kwargs):
         ''' :param item_type: :class:`Field` instance used for validation and (un)wrapping
             :param min_capacity: minimum number of items contained in values
@@ -193,8 +192,7 @@ class ListField(SequenceField):
 
 class SetField(SequenceField):
     ''' Field representing a python set.
-        
-        .. seealso:: :class:`SequenceField`'''
+    '''
     def __init__(self, item_type, **kwargs):
         ''' :param item_type: :class:`Field` instance used for validation and (un)wrapping
             :param min_capacity: minimum number of items contained in values
@@ -250,7 +248,7 @@ class ListProxy(object):
                 if v is None:
                     yield v
                     continue
-                value = self.field.dereference(session, v, 
+                value = self.field._dereference(session, v, 
                                                allow_none=self.ignore_missing)
                 if value is None and self.ignore_missing:
                     continue
